@@ -32,12 +32,14 @@ module Lens.Micro
   (&),
   -- $ampersand-note
   (<&>),
+  -- $reverse-fmap-note
 
   -- * Setter: modifies something in a structure
   -- $setters-note
   ASetter, ASetter',
   sets,
   (%~), over,
+  (<>~),
   (.~), set,
   (?~),
   (<%~), (<<%~), (<<.~),
@@ -112,10 +114,14 @@ import Data.Tuple
 import qualified Data.Foldable as F
 import Unsafe.Coerce
 
-#if __GLASGOW_HASKELL__ >= 710
+#if MIN_VERSION_base(4,8,0)
 import Data.Function ((&))
 #endif
 
+#if MIN_VERSION_base(4,11,0)
+import Data.Functor ((<&>))
+#endif
+
 -- This is for the reimplementation of State
 #if MIN_VERSION_base(4,9,0)
 import qualified Control.Monad.Fail as Fail
@@ -127,7 +133,7 @@ import qualified Control.Monad.Fail as Fail
 -}
 
 
-#if __GLASGOW_HASKELL__ < 710
+#if !(MIN_VERSION_base(4,8,0))
 {- |
 '&' is a reverse application operator. This provides notational convenience. Its precedence is one higher than that of the forward application operator '$', which allows '&' to be nested in '$'.
 -}
@@ -161,7 +167,19 @@ or this:
 @
 -}
 
+#if !(MIN_VERSION_base(4,11,0))
 {- |
+Flipped version of '<$>'.
+-}
+(<&>) :: Functor f => f a -> (a -> b) -> f b
+(<&>) x f = f <$> x
+{-# INLINE (<&>) #-}
+
+infixl 1 <&>
+#endif
+
+{- $reverse-fmap-note
+
 ('<&>') is flipped ('<$>'):
 
 @
@@ -184,11 +202,6 @@ With ('<&>') you can get rid of parentheses and move the long lambda expression
      Nothing  -> 'pure' map
 @
 -}
-(<&>) :: Functor f => f a -> (a -> b) -> f b
-(<&>) x f = f <$> x
-{-# INLINE (<&>) #-}
-
-infixl 1 <&>
 
 -- Setting -----------------------------------------------------------------
 
@@ -290,6 +303,18 @@ over :: ASetter s t a b -> (a -> b) -> s -> t
 over l f = runIdentity #. l (Identity #. f)
 {-# INLINE over #-}
 
+{- |
+('<>~') appends a value monoidally to the target.
+
+>>> ("hello", "goodbye") & both <>~ " world!"
+("hello world!", "goodbye world!")
+-}
+(<>~) :: (Monoid a) => ASetter s t a a -> a -> s -> t
+(<>~) l a = over l (`mappend` a)
+{-# INLINE (<>~) #-}
+
+infixr 4 <>~
+
 {- |
 ('.~') assigns a value to the target. It's the same thing as using ('%~') with 'const':
 
@@ -386,6 +411,8 @@ Since it does getting in addition to setting, you can't use it with 'ASetter' (b
 (<%~) l f = l (join (,) . f)
 {-# INLINE (<%~) #-}
 
+infixr 4 <%~
+
 {- |
 This is a version of ('%~') which modifies the structure and returns it along with the old value:
 
@@ -403,6 +430,8 @@ Simpler type signatures:
 (<<%~) l f = l (\a -> (a, f a))
 {-# INLINE (<<%~) #-}
 
+infixr 4 <<%~
+
 {- |
 This is a version of ('.~') which modifies the structure and returns it along with the old value:
 
@@ -420,6 +449,8 @@ Simpler type signatures:
 (<<.~) l x = l (\a -> (a, x))
 {-# INLINE (<<.~) #-}
 
+infixr 4 <<.~
+
 -- Getting -----------------------------------------------------------------
 
 {- $getters-note
@@ -999,7 +1030,7 @@ And now combine them into a traversal that conditionally traverses the value it'
 
 @
 filtered :: (a -> Bool) -> 'Traversal'' a a
-filtered p s = if p s then f s else 'pure' s
+filtered p f s = if p s then f s else 'pure' s
 @
 
 By the way, note that 'filtered' can generate illegal traversals – sometimes this can bite you. In particular, an optimisation that should be safe becomes unsafe. (To the best of my knowledge, this optimisation never happens automatically. If you just use 'filtered' to modify/view something, you're safe. If you don't define any traversals that use 'filtered', you're safe too.)
